@@ -1,13 +1,13 @@
 import tarfile
-from pathlib import Path
 
 from click import confirm, prompt, secho
 
+from indico_install.config import D_PATH
 from indico_install.utils import convertb64, find_gcs_key, run_cmd
 
 
-def auth_with_gsutil(deployment_root, raise_missing_key=False):
-    gcs_key = find_gcs_key(deployment_root, quiet=not raise_missing_key)
+def auth_with_gsutil(raise_missing_key=False):
+    gcs_key = find_gcs_key(quiet=not raise_missing_key)
     if not gcs_key:
         if raise_missing_key:
             raise AssertionError("Unable to find a key for Google auth")
@@ -36,14 +36,14 @@ def postgres_input(conf):
     conf["postgres"]["app"].update({"host": host, "password": password, "user": user})
 
 
-def download_indicoapi_data(deployment_root, version=None, extract=True):
+def download_indicoapi_data(version=None, extract=True):
     indicoapi_version = version or prompt(
         "Version of api model data to download", default="v10"
     )
     indicoapi_tar = f"indicoapi_data_{indicoapi_version}.tar.gz"
 
-    tar_path = Path(deployment_root) / indicoapi_tar
-    data_path = Path(deployment_root) / f"indicoapi_data_{indicoapi_version}"
+    tar_path = D_PATH / indicoapi_tar
+    data_path = D_PATH / f"indicoapi_data_{indicoapi_version}"
     if not data_path.exists() or confirm(
         f"Overwrite existing directory {data_path}", default=True
     ):
@@ -52,7 +52,7 @@ def download_indicoapi_data(deployment_root, version=None, extract=True):
         else:
             run_cmd(
                 f"mkdir -p {data_path} && "
-                f"gsutil cp -r gs://indicoapi-data/{indicoapi_tar} {deployment_root}"
+                f"gsutil cp -r gs://indicoapi-data/{indicoapi_tar} {D_PATH}"
             )
             assert tar_path.exists(), "Unable to download indicoapi_data successfully"
         if extract:
